==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_br.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="br" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klikit war an ikon barrenn-stad
pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Tapadenn skramm</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Chomet eo sac&apos;het an enrollañ. Enrollit e-barzh ur c&apos;havlec&apos;h personel eta.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Gwelet</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Tapadenn-skramm echuet</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>zonenn diuzañ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enrollet e-barzh %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Gwelet</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Enrollañ echuet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enrollet e-barzh %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enrollañ</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>An dapadenn-skramm a loc&apos;ho a-benn %1 eilenn</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Skrivit ho testenn amañ</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Loc&apos;hañ/Tapadenn-skramm</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Kuitaat/Enrollañ</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Tresadenn</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Brasadur ar ment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Arventennoù</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Loc&apos;hañ buan</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Tapadenn-skramm eus ar prenestr</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Dale an dapadenn-skramm</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tapadenn-skramm klok</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Skouergornek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsenn</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linenn</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kreion</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testenn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Brasaat an uhelder</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Brasaat an uhelder war-draoñ</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Brasaat al ledander a-gleiz</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Brasaat al ledander a-zehoù</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Bihanaat an uhelder</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Bihanaat an uhelder war-draoñ</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Bihanaat al ledander a-gleiz</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Bihanaat al ledander a-zehoù</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Skoazell</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Diskouez ar berradurioù</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Kregiñ da enrollañ</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Dibarzhioù</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Dispis</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Son enaouet</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Sistem aodio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Son lazhet</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Diskouez pa vizskriver</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Kuzhat pa vizskriver</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webkam enaouet</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webkam lazhet</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Diskouez ar c&apos;hlik</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Dibarzhioù</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Stumm:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Skouergornek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsenn</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linenn</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Bir</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kreion</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testenn</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Enrollañ e-barzh</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Burev</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Skeudennoù</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Teuliad</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Stumm</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Enrolladennoù</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klikit war an ikon barrenn-stad
pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Tapadenn skramm</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Chomet eo sac&apos;het an enrollañ. Enrollit e-barzh ur c&apos;havlec&apos;h personel eta.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Gwelet</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Tapadenn-skramm echuet</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>zonenn diuzañ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enrollet e-barzh %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Gwelet</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Enrollañ echuet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enrollet e-barzh %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enrollañ</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>An dapadenn-skramm a loc&apos;ho a-benn %1 eilenn</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Skrivit ho testenn amañ</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Loc&apos;hañ/Tapadenn-skramm</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Kuitaat/Enrollañ</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Brasadur ar ment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Arventennoù</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Loc&apos;hañ buan</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Tapadenn-skramm eus ar prenestr</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Dale an dapadenn-skramm</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tapadenn-skramm klok</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Skouergornek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsenn</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linenn</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kreion</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testenn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Brasaat an uhelder</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Brasaat an uhelder war-draoñ</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Brasaat al ledander a-gleiz</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Brasaat al ledander a-zehoù</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Bihanaat an uhelder</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Bihanaat an uhelder war-draoñ</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Bihanaat al ledander a-gleiz</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Bihanaat al ledander a-zehoù</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Skoazell</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Diskouez ar berradurioù</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Kregiñ da enrollañ</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Dibarzhioù</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Dispis</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Son enaouet</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Sistem aodio</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Son lazhet</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Diskouez pa vizskriver</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Kuzhat pa vizskriver</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webkam enaouet</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webkam lazhet</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Diskouez ar c&apos;hlik</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Dibarzhioù</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Stumm:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Skouergornek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsenn</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linenn</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Bir</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kreion</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testenn</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Enrollañ e-barzh</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Burev</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Skeudennoù</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Teuliad</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Stumm</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Kuitaat</translation>
    </message>
</context>
</TS>
